@@ -1,5 +1,6 @@
 import os
 import json
+from functools import partial
 
 import dash
 import flask
@@ -15,10 +16,18 @@ from dash._utils import (
     format_tag
 )
 
-from .utilities import (
-    BASE_API_URL,
-    call_get_requests
+from .api import (
+    analysis_list_view,
+    analysis_detail_view,
+    analysis_run_list_view,
+    analysis_run_detail_view,
+    analysis_export_create_view,
+    analysis_send_create_view,
+    analysis_send_detail_view,
+    compute_view
 )
+from .utilities import is_authenticated
+
 
 _app_entry = """
     <main id="AnalyticsAppsUI-container">
@@ -31,7 +40,6 @@ _report_sidebar_entry_id_ = 'AnalyticsAppsUI-sidebar-container'
 class OAPDash(dash.Dash):
     static_files = {
         'css': [
-            # 'bootstrap.min.css',
             'main.wrapper.css'
         ],
         'js': [
@@ -41,6 +49,8 @@ class OAPDash(dash.Dash):
 
     def __init__(self, **kwargs):
         self.route = kwargs.pop('route')
+        self.func_compute = kwargs.pop('func_compute')
+
         self.in_store_id = "_oap_data_in_" + self.route
         self.out_store_id = "_oap_data_out_" + self.route
 
@@ -52,15 +62,16 @@ class OAPDash(dash.Dash):
 
     def init_app(self, app=None):
         """
-        serve custom static files
+        called when the app is initiated, called only once
+        register api endpoints and custom static resources
         """
         super(OAPDash, self).init_app(app)
 
-        # serve the wrapper's media
         assets_folder = os.path.join(
             os.path.dirname(os.path.abspath(__file__)), 'analysis-wrapper'
         )
 
+        # register static files for wrapper
         self.server.register_blueprint(
             flask.Blueprint(
                 'analytics_sdk_assets',
@@ -73,15 +84,19 @@ class OAPDash(dash.Dash):
             )
         )
 
-        # register manifest file
+        # register manifest files
         self._add_url("opsramp-analytics-utils/<string:file_name>", self.serve_resource)
         self._add_url("asset-manifest.json", self.serve_manifest)
 
-    def is_authenticated(self):
-        url = f'{BASE_API_URL}/api/v2/alertTypes'
-        res = call_get_requests(url)
-
-        return res.status_code == 200
+        # register api endpoints
+        self._add_url("analyses/", analysis_list_view, ['GET', 'POST'])
+        self._add_url("analyses/<string:id>/", analysis_detail_view, ['PUT', 'GET', 'DELETE'])
+        self._add_url("analysis-runs/", analysis_run_list_view, ['GET'])
+        self._add_url("analysis-runs/<string:id>/", analysis_run_detail_view, ['GET'])
+        self._add_url("analysis-sends/", partial(analysis_send_create_view, self.func_compute), ['POST'])
+        self._add_url("analysis-sends/<string:id>/", analysis_send_detail_view, ['DELETE'])
+        self._add_url("analysis-exports/", analysis_export_create_view, ['POST'])
+        self._add_url("compute", partial(compute_view, self.func_compute), ['POST'])
 
     def _index(self, *args, **kwargs):  # pylint: disable=unused-argument
         scripts = self._generate_scripts_html()
@@ -125,17 +140,11 @@ class OAPDash(dash.Dash):
         return index
 
     def index(self, *args, **kwargs):  # pylint: disable=unused-argument
-        index = self._index(args, kwargs)
-
-        # check auth
-        REQUIRE_AUTH_REDIRECT = os.getenv('REQUIRE_AUTH_REDIRECT') == 'true'
-        if not REQUIRE_AUTH_REDIRECT or self.is_authenticated():
-            return index
+        if is_authenticated():
+            resp = self._index(args, kwargs)
+            return resp
         else:
-            PLATFORM_ROUTE = os.getenv("PLATFORM_ROUTE", '')
-            redirect_url = f"/tenancy/web/login?cb=/{PLATFORM_ROUTE}"
-
-            return flask.redirect(redirect_url, code=302)
+            return flask.Response('Not authorized', status=401)
 
     def serve_manifest(self):
         return {
@@ -195,12 +204,14 @@ class OAPDash(dash.Dash):
         dev = self._dev_tools.serve_dev_bundles
         body = f"var oap_config = {json.dumps(self._config(), cls=plotly.utils.PlotlyJSONEncoder)};\n"
 
+        oap_app_id = os.getenv('OAP_APP_ID')
+        body += f"var OAP_APP_ID = '{oap_app_id}';\n"
+        body += f"var OAP_IN_STORE_ID = '{self.in_store_id}';\n"
+        base_path = self.config.requests_pathname_prefix.rstrip('/')
+        body += f"var OAP_BASE_PATH = '{base_path}';\n"
+
         # external js files
         external_links = self.config.external_scripts
-        # urllib
-
-        # inline scripts
-        # self._inline_scripts
 
         # oap js files
         if os.getenv("INCLUDE_WRAPPER") == "true":
@@ -238,28 +249,9 @@ class OAPDash(dash.Dash):
                     if not is_dynamic_resource:
                         _body = pkgutil.get_data(resource["namespace"], rel_path).decode("utf-8")
                         body += self.pre_process(_body, rel_path, dev)
-            # elif "external_url" in resource:
-            #     if not is_dynamic_resource:
-            #         if isinstance(resource["external_url"], str):
-            #             srcs.append(resource["external_url"])
-            #         else:
-            #             srcs += resource["external_url"]
-            # elif "asset_path" in resource:
-            #     static_url = self.get_asset_url(resource["asset_path"])
-            #     # Add a cache-busting query param
-            #     srcs.append(static_url)
 
         body += "var renderer = new DashRenderer();\n"
 
-        app_service_base_url = os.getenv('APP_SERVICE_BASE_URL')
-        if os.getenv('ON_PROXY') == 'true':
-            app_service_base_url = 'https://localhost' + app_service_base_url[app_service_base_url.index('/oap-api'):]
-
-        oap_app_id = os.getenv('OAP_APP_ID')
-        body += f"var OAP_API_URL = '{app_service_base_url}';\n"
-        body += f"var OAP_APP_ID = '{oap_app_id}';\n"
-        body += f"var OAP_IN_STORE_ID = '{self.in_store_id}';\n"
-
         response = flask.Response(body, mimetype='application/javascript')
 
         return response
